==> ejc-bfyjerp-api-3.0.0-20241107.102102-19-sources.jar: com/ejianc/business/bid/vo/CALockVO.java <==
package com.ejianc.business.bid.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 投标管理-CA锁登记表
 * 
 * @author generator
 * 
 */
public class CALockVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; //编码
    private String belongArea; // CA锁所属区域
    private String belongWebAddr; // 所属区域网址
    private Long employeeId; // 编制人ID
    private String employeeName; // 编制人
    
    private List<CALockDetailVO> detailList = new ArrayList<>(); // 投标管理-CA锁登记子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getBelongArea() {
        return belongArea;
    }

    public void setBelongArea(String belongArea) {
        this.belongArea = belongArea;
    }
    public String getBelongWebAddr() {
        return belongWebAddr;
    }

    public void setBelongWebAddr(String belongWebAddr) {
        this.belongWebAddr = belongWebAddr;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public List<CALockDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CALockDetailVO> detailList) {
        this.detailList = detailList;
    }
}

==> ejc-bfyjerp-api-3.0.0-20250410.073645-193-sources.jar: com/ejianc/business/bid/vo/CALockVO.java <==
package com.ejianc.business.bid.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 投标管理-CA锁登记表
 * 
 * @author generator
 * 
 */
public class CALockVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; //编码
    private String belongArea; // CA锁所属区域
    private String belongWebAddr; // 所属区域网址
    private Long employeeId; // 编制人ID
    private String employeeName; // 编制人

    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endTime; // 到期时间

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    private List<CALockDetailVO> detailList = new ArrayList<>(); // 投标管理-CA锁登记子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getBelongArea() {
        return belongArea;
    }

    public void setBelongArea(String belongArea) {
        this.belongArea = belongArea;
    }
    public String getBelongWebAddr() {
        return belongWebAddr;
    }

    public void setBelongWebAddr(String belongWebAddr) {
        this.belongWebAddr = belongWebAddr;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public List<CALockDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CALockDetailVO> detailList) {
        this.detailList = detailList;
    }
}
